//
// System.Data.Sql.ISqlConnection
//
// Authors:
//   Tim Coleman (tim@timcoleman.com)
//   Umadevi S (sumadevi@novell.com)
//
// Copyright (C) Tim Coleman, 2003
//

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

namespace System.Data.Sql {
	public interface ISqlConnection : IDbConnection, IDisposable
	{
		#region Properties

		string DataSource { get; }
		string ServerVersion { get; }

		#endregion // Properties

		#region Methods

		new ISqlTransaction BeginTransaction ();
		new ISqlTransaction BeginTransaction (IsolationLevel iso);
		ISqlTransaction BeginTransaction (string transactionName);
		ISqlTransaction BeginTransaction (IsolationLevel iso, string transactionName);
		new ISqlCommand CreateCommand ();
		ISqlCommand CreateCommand (string commandText);
		ISqlExecutionContext CreateExecutionContext (SqlDefinition sqlDefinition);

		#endregion // Methods
	}
}

#endif
